@@ -688,9 +688,10 @@ sub getfont {
 		  gdMediumBoldFont => $img_class->gdMediumBoldFont(),
 		  gdLargeFont      => $img_class->gdLargeFont(),
 		  gdGiantFont      => $img_class->gdGiantFont(),
+		  sanserif         => $img_class->gdSmallFont(),
     		 };
 
-    my $gdfont = $ref->{$font};
+    my $gdfont = $ref->{$font} || $ref->{gdSmallFont};
     $self->configure($option => $gdfont);
     return $gdfont;
   }
@@ -948,7 +949,6 @@ sub draw {
   $self->panel->startGroup($gd);
 
   my $connector = $self->connector;
-
   if (my @parts = $self->parts) {
 
     # invoke sorter if user wants to sort always and we haven't already sorted
