@@ -7,6 +7,17 @@ use base qw(Bio::Graphics::Glyph::wiggle_minmax
 use IO::File;
 use File::Spec;
 
+# Added pad_top subroutine (pad_top of Glyph.pm, which is called when executing $self->pad_top
+# returns 0, so we need to override it here)
+sub pad_top {
+  my $self = shift;
+  my $pad = $self->Bio::Graphics::Glyph::generic::pad_top(@_);
+  if ($pad < ($self->font('gdTinyFont')->height)) {
+    $pad = $self->font('gdTinyFont')->height;  # extra room for the scale
+  }
+  $pad;
+}
+
 # we override the draw method so that it dynamically creates the parts needed
 # from the wig file rather than trying to fetch them from the database
 sub draw {
@@ -138,7 +149,7 @@ sub draw_plot {
     my $y_scale  = $max_score > $min_score ? $height/($max_score-$min_score)
 	                                   : 1;
     my $x = $left;
-    my $y = $top + $self->pad_top;
+    my $y = $top;
     
     my $x_scale     = $self->scale;
     my $panel_start = $self->panel->start;
@@ -147,6 +158,8 @@ sub draw_plot {
 	                  ? $feature->start 
 			  : $panel_start;
 
+    $y += $self->pad_top;
+
     # position of "0" on the scale
     my $y_origin = $min_score <= 0 ? $bottom - (0 - $min_score) * $y_scale : $bottom;
     $y_origin    = $top if $max_score < 0;
@@ -183,7 +196,7 @@ sub draw_plot {
     if ($type eq 'boxes') {
 	for (@points) {
 	    my ($x1,$y1,$x2,$y2,$color,$lw) = @$_;
-	    $self->filled_box($gd,$x1,$y1,$x2,$y2,$color,$color,$lw);
+	    $self->filled_box($gd,$x1,$y1,$x2,$y2,$color,$color,$lw) if $y1-$y2;
 	}
     }
 
@@ -215,7 +228,7 @@ sub draw_plot {
 	for (@points) {
 	    my ($x1, $y1, $x2, $y2, $color, $lw)  = @$_;
 	    my ($y_start,$y_end) = $y1 < $y_origin ? ($y1,$y_origin) : ($y_origin,$y1);
-	    $self->filled_box($gd,$current->[0],$y_start,$x2,$y_end,$color,$color,1);
+	    $self->filled_box($gd,$current->[0],$y_start,$x2,$y_end,$color,$color,1) if $y1-$y2;
 	    $current = $_;
 	}	
     }
